@@ -1,4 +1,8 @@
-use crate::{driver::RigDriver, rig::RigUpdateParams, transform::Transform};
+use std::marker::PhantomData;
+
+use crate::{
+    driver::RigDriver, handedness::Handedness, rig::RigUpdateParams, transform::Transform,
+};
 
 /// Locks/constrains the position of the camera to one or more axes
 #[derive(Debug)]
@@ -48,8 +52,8 @@ impl Default for LockPosition {
     }
 }
 
-impl RigDriver for LockPosition {
-    fn update(&mut self, params: RigUpdateParams) -> Transform {
+impl<H: Handedness> RigDriver<H> for LockPosition {
+    fn update(&mut self, params: RigUpdateParams<H>) -> Transform<H> {
         let mut delta_pos = params.parent.position;
         delta_pos.x = self.x.unwrap_or(delta_pos.x);
         delta_pos.y = self.y.unwrap_or(delta_pos.y);
@@ -57,6 +61,7 @@ impl RigDriver for LockPosition {
         Transform {
             position: delta_pos,
             rotation: params.parent.rotation,
+            phantom: PhantomData,
         }
     }
 }
