@@ -1,6 +1,10 @@
+use std::marker::PhantomData;
+
 use glam::Quat;
 
-use crate::{driver::RigDriver, rig::RigUpdateParams, transform::Transform};
+use crate::{
+    driver::RigDriver, handedness::Handedness, rig::RigUpdateParams, transform::Transform,
+};
 
 /// Directly sets the rotation of the camera
 #[derive(Default, Debug)]
@@ -14,11 +18,12 @@ impl Rotation {
     }
 }
 
-impl RigDriver for Rotation {
-    fn update(&mut self, params: RigUpdateParams) -> Transform {
+impl<H: Handedness> RigDriver<H> for Rotation {
+    fn update(&mut self, params: RigUpdateParams<H>) -> Transform<H> {
         Transform {
             position: params.parent.position,
             rotation: self.rotation,
+            phantom: PhantomData,
         }
     }
 }
