@@ -7,14 +7,12 @@
 //! rotation via yaw and pitch angles. Each frame, driver parameters can be modified,
 //! and will affect the subsequent call to [`CameraRig::update`], which provides the final camera transformation.
 //!
-//! Please note that `dolly` currently assumes the right-handed OpenGL-style coordinate system.
-//!
 //! # Example
 //!
 //! ```
 //! use dolly::prelude::*;
 
-//! let mut camera = CameraRig::builder()
+//! let mut camera: CameraRig = CameraRig::builder()
 //!     .with(Position::new(glam::Vec3::ZERO))
 //!     .with(YawPitch::new())
 //!     .with(Smooth::new_position_rotation(1.0, 1.0))
@@ -35,6 +33,7 @@
 
 pub mod driver;
 pub mod drivers;
+pub mod handedness;
 pub mod prelude;
 pub mod rig;
 pub mod transform;
