@@ -1,17 +1,25 @@
 use core::fmt::Debug;
 use glam::{Quat, Vec3};
+use std::marker::PhantomData;
+
+use crate::handedness::Handedness;
 
 /// A thin wrapper over a `Vec3` and a `Quat`
 #[derive(Clone, Copy, Debug)]
-pub struct Transform {
+pub struct Transform<H: Handedness> {
     pub position: Vec3,
     pub rotation: Quat,
+    pub phantom: PhantomData<H>,
 }
 
-impl Transform {
+impl<H: Handedness> Transform<H> {
     ///
     pub fn from_position_rotation(position: Vec3, rotation: Quat) -> Self {
-        Self { position, rotation }
+        Self {
+            position,
+            rotation,
+            phantom: PhantomData,
+        }
     }
 
     ///
@@ -29,14 +37,15 @@ impl Transform {
         self.rotation * Vec3::Y
     }
 
-    /// -Z
+    /// +/-Z
     pub fn forward(&self) -> Vec3 {
-        self.rotation * -Vec3::Z
+        self.rotation * H::FORWARD
     }
 
     ///
-    pub const IDENTITY: Transform = Transform {
+    pub const IDENTITY: Transform<H> = Transform {
         position: Vec3::ZERO,
         rotation: Quat::IDENTITY,
+        phantom: PhantomData,
     };
 }
